;; Generated package description from system-packages.el  -*- no-byte-compile: t -*-
(define-package "system-packages" "1.0.12.0.20230805.22742" "functions to manage system packages" '((emacs "24.3")) :commit "14b2cc3d54cc26692fb4a71ae4befee1f0b15e1b" :authors '(("J. Alexander Branham" . "alex.branham@gmail.com")) :maintainer '("J. Alexander Branham" . "alex.branham@gmail.com") :url "https://gitlab.com/jabranham/system-packages")
